tdlib: Algorithms for computing tree decompositions
===================================================

Description
-----------

Providing algorithms concerning treedecompositions

website: https://github.com/freetdi/tdlib

License
-------

GNU General Public License v2


SPKG Maintainers
----------------

Lukas Larisch (lukas.larisch@kaust.edu.sa)


Upstream Contact
----------------

- Lukas Larisch (lukas.larisch@kaust.edu.sa)
- git-repo: https://github.com/freetdi/tdlib

Dependencies
------------

-  None
